Learn R Programming

spidR (version 1.0.2)

species: Get species from higher taxa.

Description

Get species within given families or genera from the World Spider Catalogue.

Usage

species(tax, order = FALSE)

Arguments

tax

A taxon name or vector with taxa names.

order

Order species names alphabetically.

Value

A vector with species names.

Details

This function will get all species currently listed for given families or genera from the World Spider Catalogue (2021).

References

World Spider Catalog (2021). World Spider Catalog. Version 22.0. Natural History Museum Bern, online at http://wsc.nmbe.ch. doi: 10.24436/2.

Examples

Run this code
# NOT RUN {
species("Amphiledorus")
species(tax = c("Amphiledorus", "Nemesiidae"), order = TRUE)
# }

Run the code above in your browser using DataLab