powered by
Get species within given families or genera from the World Spider Catalogue.
species(tax, order = FALSE)
A taxon name or vector with taxa names.
Order species names alphabetically.
A vector with species names.
This function will get all species currently listed for given families or genera from the World Spider Catalogue (2021).
World Spider Catalog (2021). World Spider Catalog. Version 22.0. Natural History Museum Bern, online at http://wsc.nmbe.ch. doi: 10.24436/2.
# NOT RUN { species("Amphiledorus") species(tax = c("Amphiledorus", "Nemesiidae"), order = TRUE) # }
Run the code above in your browser using DataLab